pub struct Helpers {
pub load: FuncId,
pub store: FuncId,
pub divisions: [FuncId; 4],
}Expand description
The runtime entry points compiled code calls when an access cannot be settled inline, as declared in the module.
Fields
load: FuncIdstore: FuncIddivisions: [FuncId; 4]The 128-bit divisions, in Division order.