Module jit
qcode_
jit
0.4.0
Module jit
Module Items
Structs
In crate qcode_
jit
qcode_jit
Module
jit
Owning, caching and running compiled blocks.
Structs

Jit
A JIT backend: compiles blocks on first use and runs them thereafter.
JitStats
How much work the JIT is taking, and how much it is declining.